<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" xmlns:op="utc.fr:ics/opale"
    xmlns:dc="urn:unit-c.fr:schema:dublincore:v1"
    xmlns:db="urn:unit-c.fr:schema:docbook:v1"
    exclude-result-prefixes="sc sp op">
    <xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes"/>
    <xsl:param name="vDialog"/>
    <xsl:param name="vAgent"/>
    
    
    <!-- Root de Text -->
    <xsl:template match="op:text">
        <db:text>
            <xsl:apply-templates/>
        </db:text>
    </xsl:template>
    
    <!-- Paragraphe -->
    <xsl:template match="sc:para">
        <db:simpara>
            <xsl:apply-templates/>
        </db:simpara>
    </xsl:template>
    
    
    <xsl:template match="sc:itemizedList">
        <db:itemizedList>
            <xsl:apply-templates/>
        </db:itemizedList>
    </xsl:template>
    
    
    <xsl:template match="sc:orderedList">
        <db:orderedList>
            <xsl:apply-templates/>
        </db:orderedList>
    </xsl:template>
    
    
    <xsl:template match="sc:listItem">
        <db:listitem>
            <xsl:apply-templates/>
        </db:listitem>
    </xsl:template>
    
    <!-- Inline -->
    <xsl:template match="sc:inlineStyle[@role='emphasis']">
        <db:emphasis>
            <xsl:apply-templates/>
        </db:emphasis>
    </xsl:template>
    
    <xsl:template match="sc:note">
        <db:footnote>
            <xsl:apply-templates/>
        </db:footnote>
    </xsl:template>
    
    <xsl:template match="sc:phrase[@role='quote']">
        <db:quote>
            <xsl:apply-templates/> : <xsl:apply-templates select="@xml:lang"/>
        </db:quote>
    </xsl:template>
    
    <xsl:template match="sc:textLeaf[@role='trademark']">
        <db:trademark class="trade">
            <xsl:apply-templates/>
        </db:trademark>
    </xsl:template> 
    
    <xsl:template match="sc:textLeaf[@role='registered']">
        <db:trademark class="registered">
            <xsl:apply-templates/>
        </db:trademark>
    </xsl:template>
    
    <xsl:template match="sc:textLeaf[@role='copyright']">
        <db:trademark class="copyright">
            <xsl:apply-templates/>
        </db:trademark>
    </xsl:template>
    
    <!-- sc:uLink à finir : acronym, glossaire, articleCode, biblio, ref -->
    <xsl:template match="sc:uLink">
        <xsl:choose>
            <xsl:when test="@role='biblio'">
                <biblioref>
                    <xsl:apply-templates/>
                </biblioref>
            </xsl:when>
            <xsl:when test="@role='acronyme'">
                <acronym>
                    <xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes"/>
                </acronym>
            </xsl:when>
            <xsl:when test="@url!=''">
                <db:ulink>
                    <xsl:apply-templates/> : <xsl:apply-templates select="@url"/>
                </db:ulink>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="sc:textLeaf[@role='command']">
        <db:command>
            <xsl:apply-templates/>
        </db:command>
    </xsl:template>
    
    <xsl:template match="sc:textLeaf[@role='email']">
        <db:email>
            <xsl:apply-templates/>
        </db:email>
    </xsl:template>
    
    <xsl:template match="sc:inlineImg[@role='guiicon']">
        <db:guiicon refUri="{getUrl(gotoSubModel(), '')}">
            <!--<xsl:apply-templates select="@sc:refUri"/>-->
            <!--<xsl:value-of select="getContent(gotoSubModel(), '')" disable-output-escaping="yes" />-->
        </db:guiicon>
    </xsl:template>
    
    <xsl:template match="sc:inlineImg[@role='formulaInline']">
        <db:inlineequation>
            <!--<xsl:apply-templates select="@sc:refUri"/>--> 
            <xsl:value-of select="getContent(gotoSubModel(), '')" disable-output-escaping="yes" />
        </db:inlineequation>
    </xsl:template>
    
    
    <xsl:template match="*"/>
    
    
</xsl:stylesheet>
